
import { useMutation } from '@tanstack/react-query';
import { criminalProceduresRoute } from '.';
import { queryClient } from '../../query-client';
import { QUERY_KEYS } from '../../query-keys';

export type CriminalProcedureCreate = {
  procedureNumber: string;
  date: string;
  description: string;
  cityId: string;
  crimeId: string;
  procedureType: string;
};

export const useCreateCriminalProcedure = () => {
  return useMutation({
    mutationFn: (criminalProcedure: CriminalProcedureCreate) =>
      criminalProceduresRoute.post<CriminalProcedureCreate, {}>('', criminalProcedure),
    onSuccess: () => {
      queryClient.invalidateQueries({ queryKey: [QUERY_KEYS.criminalProcedures] });
    },
  });
};

export const useDeleteCriminalProcedure = (id: string) => {
  return useMutation({
    mutationFn: () =>
      criminalProceduresRoute.delete<CriminalProcedureCreate, {}>(id),
    onSuccess: () => {
      queryClient.invalidateQueries({ queryKey: [QUERY_KEYS.criminalProcedures] });
    },
  });
};
