import { useQuery } from '@tanstack/react-query';
import auth from '../../authentication';
import { documentDownloadRoute, documentForCriminalProcedureRoute } from './index';
import { QUERY_KEYS } from '../../query-keys';
import * as FileSystem from 'expo-file-system';
export interface DocumentData {
  id: string;
  name: string;
  size: number;
  active: boolean;
  date: string;
  criminalProcedure: {
    id: string;
    procedureType: string;
    number: string;
    crime: {
      name: string;
    };
    city: {
      name: string;
    };
    date: string;
  };
}

export const useGetDocumentForCriminalProcedure = (procedureId: string, enabled: boolean) =>
  useQuery<DocumentData[]>({
    queryKey: [QUERY_KEYS.documentForCriminalProcedure, procedureId],
    queryFn: async () => {
      const response = await documentForCriminalProcedureRoute(procedureId).get('');
      return response.data.content;
    },
    enabled: true,
  });

export const useDownloadFile = async (id: string, fileName: string) => {
  const response = await auth.getAutenticationToken();
  return FileSystem.createDownloadResumable(
    documentDownloadRoute(id).getUri(),
    FileSystem.documentDirectory + fileName,
    {
      headers: {
        "Authorization": `Bearer ${response.token}`
      }
    }
  );

};