import { useMutation } from "@tanstack/react-query";
import { uploadRoute } from '.';
import { queryClient } from "../../query-client";
import { QUERY_KEYS } from "../../query-keys";

export type File = {
    date: string;
    name: string;
    urlFile: any;
    procedureId: string;
}

export const useUploadFile = () => {
    return useMutation({
        mutationFn: (file: File) => {
            const formData = new FormData();
            formData.append('file', { uri: file.urlFile.assets![0].uri, name: file.name, type: file.urlFile.assets![0].mimeType ?? 'image/jpeg' } as any);
            formData.append('name', file.name);
            formData.append('date', file.date
            .split(', ')[0]
            .split('/')
            .reverse()
            .join('-')
            .replace(/\b\d\b/g, (match) => match.padStart(2, '0')));
            formData.append('procedureId', file.procedureId);
            return uploadRoute.post<FormData, {}>('', formData, {
                headers: { "Content-Type": 'multipart/form-data' }
            })
        },
        onSuccess: (data: any) => {
            queryClient.invalidateQueries({ queryKey: [QUERY_KEYS.documentForCriminalProcedure, data.data.criminalProcedure.id] });
        }
    });
};
