import { Environment, UrlType } from "./enum";
import { createHttpClient } from "./http-client";
import Constants from "expo-constants";

export function getEnvironmentRoute(type: UrlType): string {
    switch (process.env.EXPO_PUBLIC_APP_ENV) {
        case Environment.Local:
            return getLocalUrl(type);
        case Environment.Development:
        case Environment.Homologation:
        default:
            return getUrl(type);
    }
}

export const getBaseApi = (type: UrlType) => {
    const baseRoute = getEnvironmentRoute(type);
    return createHttpClient(baseRoute);
};

const getLocalUrl = (type: UrlType) => {
    const { linkingUri } = Constants;
    const handledUrl = linkingUri.split("//")[1].split(":")[0];
    switch (type) {
        case UrlType.API:
            return "http://" + handledUrl + ":8081";
        case UrlType.AUTH:
            return "http://" + handledUrl + ":8080";
        case UrlType.STRAPI:
            return 'https://strapi-dev.vitimasdecrime.site';
    }

}

const getUrl = (type: UrlType) => {
    switch (type) {
        case UrlType.API:
            return `https://api-${process.env.EXPO_PUBLIC_APP_ENV}.vitimasdecrime.site`;
        case UrlType.AUTH:
            return `https://auth-${process.env.EXPO_PUBLIC_APP_ENV}.vitimasdecrime.site`;
        case UrlType.STRAPI:
            return `https://strapi-${process.env.EXPO_PUBLIC_APP_ENV}.vitimasdecrime.site`;
    }
}
