import React from 'react';
import { ScrollView, StyleSheet, View, Text } from 'react-native';
import ProcedureCard from '../../components/procedureCard/procedureCard';
import colors from '../../styles/colors';
import FloatingButton from '../../components/floatingButton/floatingButton';
import Exception from '../../components/error/error';
import CustomHeader from '../../components/header/header';
import { useGetCriminalProcedures } from '../../api/api/criminal-procedures/queries';
import { router } from 'expo-router';

const PROCEDURE_TYPE_OPTIONS: { [key: string]: string } = {
  PROCESS: 'Processo',
  OCCURRENCE: 'Ocorrência',
};

const ProcedureVisualization = () => {
  const { data: procedureData = [], error } = useGetCriminalProcedures(true);

  if (error) {
    return <Exception />;
  }

  return (
    <View style={styles.container}>
      <CustomHeader title="Procedimento Criminal" />
      <View style={[styles.bottomContainer]}>
        <ScrollView style={styles.bottomContainer}>
          <View style={[styles.bottomContainer, { paddingBottom: 10 }, { paddingTop: 20 }]} id='crim-procedure-header-text'>
            <Text style={styles.subTitle}>
              Abaixo estão os seus procedimentos criminais cadastrados. Clique para acessar os
              documentos relacionados
            </Text>
          </View>
          {procedureData && procedureData.map(({ id, procedureType, number, crime, city, date }) => {
            const procedureDate = new Date(`${date}T04:00:00Z`);

            const formattedDate = new Intl.DateTimeFormat('pt-BR', {
              year: 'numeric',
              month: '2-digit',
              day: '2-digit',
            }).format(procedureDate);
            return (
							<ProcedureCard
							key={id}
							procedureType={PROCEDURE_TYPE_OPTIONS[procedureType]}
							procedureNumber={number}
							crimeType={crime?.name}
							crimeLocation={city?.name}
							crimeDate={formattedDate} 
							onPress={() => router.push({ pathname: '/documents/', params: { idProcedure:  id, procedureNumber: number } })}
						/>	
            );
          })}
        </ScrollView>
        <FloatingButton id='add-criminal-procedure-btn' onPress={() => router.replace('/criminal_procedure_register/')} />
      </View>
    </View>
  );
};

const styles = StyleSheet.create({
  container: {
    backgroundColor: colors.BACKGROUND,
    height: '100%',
    marginBottom: 300
  },
  titleContainer: {
    alignItems: 'center',
    justifyContent: 'center',
    padding: 25,
    marginTop: 30,
  },
  orangeLine: {
    width: '100%',
    backgroundColor: colors.UT_ORANGE,
    height: 5,
  },
  bottomContainer: {
    backgroundColor: colors.BACKGROUND,
    paddingRight: 5,
    paddingLeft: 5,
    flex: 1,
  },

  subtitleContainer: {
    alignItems: 'center',
    justifyContent: 'center',
    marginTop: 20,
  },
  title: {
    fontWeight: 'bold',
    fontSize: 25,
    marginBottom: 5,
    alignSelf: 'center',
  },
  subTitle: {
    fontWeight: '600',
    fontSize: 16,
    color: colors.GRAY,
  },
});

export default ProcedureVisualization;
