import { SafeAreaView, ScrollView, StyleSheet, View } from 'react-native';
import { Text } from 'react-native-paper';
import ButtonComponent from '../../components/button/component_button';
import colors from '../../styles/colors';
import React from 'react';
import DocumentComponent from '../../components/document/document';
import FloatingButton from '../../components/floatingButton/floatingButton';
import { useGetDocumentForCriminalProcedure } from '../../api/api/files/queries';
import Error from '../../components/error/error';
import { useRoute } from '@react-navigation/native';
import { ProcedureData, useGetCriminalProcedureByID } from '../../api/api/criminal-procedures/queries';
import CustomHeader from '../../components/header/header';
import { router } from 'expo-router';

const DocumentsVisualization = () => {
  const route = useRoute();
  const routeParams = route.params;

  let idProcedure: string = '';

  if (typeof routeParams === 'string') {
    idProcedure = routeParams;
  } else if (
    typeof routeParams === 'object' &&
    routeParams !== null &&
    'idProcedure' in routeParams
  ) {
    idProcedure = routeParams.idProcedure as string;
  }

  let procedureNumber: string = '';

  if (typeof routeParams === 'string') {
    procedureNumber = routeParams;
  } else if (
    typeof routeParams === 'object' &&
    routeParams !== null &&
    'procedureNumber' in routeParams
  ) {
    procedureNumber = routeParams.procedureNumber as string;
  }

  const { data: documentData = [], error } = useGetDocumentForCriminalProcedure(idProcedure, true);
  const { data: procedureData = {} as ProcedureData } = useGetCriminalProcedureByID(procedureNumber, true);
  const hasDocuments = documentData.length > 0;


  const handleSwitchScreen = () => {
    router.push({ pathname: '/upload_files/', params: { procedureType: procedureData?.procedureType, procedureId: idProcedure, procedureNumber: procedureData?.number } })
  };

  if (error) {
    console.error('Erro ao buscar documentos:', error);
    return <Error />;
  }

  return (
    <SafeAreaView
      style={{
        flex: 1,
        backgroundColor: colors.BACKGROUND,
      }}
    >
      <CustomHeader
        title="Anexos"
        returnRoute='/criminal_procedure_visualization'
        subtitle={
          procedureData?.procedureType === 'PROCESS' ? `Processo nº ${procedureData?.number}` : `Ocorrência nº ${procedureData?.number}`
        }
      />
      <View style={styles.container}>
        {hasDocuments ? (
          <View style={styles.content2Container}>
            <ScrollView contentContainerStyle={styles.content2}>
              {documentData.map(({ id, name, date, size }) => {
                const documentDate = new Date(`${date}T04:00:00Z`);

                const formattedDate = new Intl.DateTimeFormat('pt-BR', {
                  year: '2-digit',
                  month: '2-digit',
                  day: '2-digit',
                }).format(documentDate);
                return (
                  <View style={styles.documentContainer} key={id}>
                    <DocumentComponent
                      crimeDate={formattedDate}
                      procedureSize={`${size}Kb`}
                      documentType={name}
                      id={id}
                    />
                  </View>
                );
              })}
            </ScrollView>
            <FloatingButton onPress={handleSwitchScreen} />
          </View>
        ) : (
          <View style={styles.content}>
            <Text style={styles.text}>
              Você ainda não possui anexos. Clique no botão abaixo para fazer upload de uma imagem
              ou documento PDF
            </Text>
            <View style={styles.buttons}>
              <ButtonComponent value="Adicionar Anexo" onClick={handleSwitchScreen} />
            </View>
          </View>
        )}
      </View>
    </SafeAreaView>
  );
};

export default DocumentsVisualization;

const styles = StyleSheet.create({
  //BUTTONS
  buttons: {
    margin: '5%',
    width: '80%',
  },

  //CONTENT PÁGINA PRINCIPAL
  container: {
    display: 'flex',
    alignItems: 'center',
    flex: 1,
    backgroundColor: colors.BACKGROUND,
  },
  text: {
    width: '75%',
    textAlign: 'center',
    fontWeight: 'bold',
    fontSize: 18,
    color: colors.EERIE_BLACK,
    marginBottom: 20,
  },
  content: {
    width: '100%',
    marginTop: '5%',
    marginBottom: '5%',
    display: 'flex',
    justifyContent: 'center',
    alignItems: 'center',
    flex: 1,
  },

  //CONTEUDO PÁGINA CASO JÁ TENHA DOCUMENTOS
  content2Container: {
    width: '100%',
    flex: 1,
    position: 'relative',
    display: 'flex',
  },
  content2: {
    margin: '5%',
    display: 'flex',
    flexDirection: 'row',
    flexWrap: 'wrap',
    justifyContent: 'space-between',
  },
  documentContainer: {
    marginBottom: '7%',
  },
});
