import { router, useLocalSearchParams } from 'expo-router';
import React, { useState } from 'react';
import { SafeAreaView, ScrollView, StyleSheet, View } from 'react-native';
import { Text } from 'react-native-paper';

import { useSignUp } from '../../api/auth/users/requests';
import HeaderSuccess from '../../assets/images/header-procedure.svg';
import Information from '../../assets/images/information.svg';
import ComponentButton from '../../components/button/component_button';
import colors from '../../styles/colors';
import general from '../../styles/general';

import InputText from '../../components/input/input';
import Link from '../../components/link/link';
import Tooltip from '../../components/tooltip/tooltip';

const TOOLTIP_1_TEXT =
  'Não se preocupe! Você poderá acompanhar todos eles dentro do aplicativo, e pode informar apenas um deles ao fazer o cadastro.';

const TOOLTIP_2_TEXT =
  'Para acessar o aplicativo, é necessário ter um Boletim de Ocorrência registrado ou um processo em andamento. Para mais informações,';

const getTooltipText = () => {
  const URL = 'https://www.delegaciaonline.rs.gov.br/dol/#!/index/perguntaseduvidasfrequentes';
  return <Link text={TOOLTIP_2_TEXT} url={URL} />;
};

const ProcedureNumber = () => {
  const form = useLocalSearchParams() as any;
  const [procedureNumber, setProcedureNumber] = useState('');

  const signUpMutation = useSignUp();

  const handleSignup = () => {
    const credentials = {
      name: form.name,
      cpf: form.cpf.replace(/\D/g, ''),
      email: form.email,
      phoneNumber: form.phone.replace(/\D/g, ''),
      password: form.password,
    };

    signUpMutation.mutate(credentials, {
      onSuccess: () => {
        router.push('/register_verification/SucessScreen');
      },
      onError: (error) => {
        router.push('/register_verification/FailScreen');
      },
    });
  };

  const handleProcedureNumber = (e: string) => {
    e = e.replace(/\D/g, '');
    setProcedureNumber(e);
  };

  return (
    <SafeAreaView style={styles.safeArea}>
      <ScrollView contentContainerStyle={styles.scrollView}>
        <HeaderSuccess style={styles.headerImage} />
        <Text style={styles.largeText}>Informe o número de processo ou ocorrência</Text>
        <Text style={styles.smallText}>
          Para que você possa ter acesso ao cadastro, é preciso informar um número de processo ou
          ocorrência
        </Text>
        <View style={styles.inputContainer}>
          <InputText
            state={procedureNumber}
            handleChange={(val) => handleProcedureNumber(val)}
            label="N˚ de procedimento criminal"
            leftIcon={<Information />}
						id=" "
          />
        </View>

        <View style={styles.buttonContainer}>
          <ComponentButton onClick={() => handleSignup()} value="Continuar" />
        </View>
        <View>
          <Tooltip text={TOOLTIP_1_TEXT}>
            <Text style={styles.informationText}>
              Tenho diversos processos que gostaria de acompanhar
            </Text>
          </Tooltip>
        </View>
        <View>
          <Tooltip text={getTooltipText()}>
            <Text style={styles.informationText}>
              Não tenho uma ocorrência registrada ou um processo em andamento.
            </Text>
          </Tooltip>
        </View>
      </ScrollView>
    </SafeAreaView>
  );
};

const styles = StyleSheet.create({
  safeArea: {
    height: '100%',
    width: '100%',
    backgroundColor: colors.BACKGROUND,
  },
  scrollView: {
    width: '100%',
    height: '100%',
    alignContent: 'center',
    alignItems: 'center',
    padding: 10,
  },
  container: {
    justifyContent: 'center',
    alignItems: 'center',
    backgroundColor: colors.VERMILION,
    paddingHorizontal: '10%',
  },
  headerImage: {
    marginBottom: 30,
    height: 150,
    marginTop: 42,
  },
  largeText: {
    textAlign: 'center',
    fontSize: general.header2.fontSize,
    fontWeight: 'bold',
    color: colors.EERIE_BLACK,
    marginVertical: 10,
  },
  smallText: {
    textAlign: 'center',
    fontSize: 16,
    fontWeight: 'normal',
    color: colors.GRAY,
    marginVertical: 10,
    width: '80%',
  },
  inputContainer: {
    width: '80%',
  },
  informationText: {
    textAlign: 'center',
    justifyContent: 'center',
    fontSize: 16,
    fontWeight: '300',
    color: colors.UT_ORANGE,
    marginBottom: 19,
  },
  buttonContainer: {
    marginVertical: 33,
    alignItems: 'center',
    display: 'flex',
    width: '80%',
  },
  icon: {
    color: colors.SELECTIVE_YELLOW,
  },
});

export default ProcedureNumber;
