import { View, StyleSheet } from 'react-native';
import colors from '../../styles/colors';
import React, { useState } from 'react';
import UploadFile from '../../components/uploadFiles/uploadFiles';
import InputText from '../../components/input/input';
import DatePicker from '../../components/datepicker/datepicker';
import { Text } from 'react-native-paper';
import CustomHeader from '../../components/header/header';
import Button from '../../components/button/component_button';
import { router } from 'expo-router';
import { useUploadFile } from '../../api/api/files/requests';
import { useRoute } from '@react-navigation/native';
import { KeyboardAwareScrollView } from 'react-native-keyboard-aware-scroll-view';

const UPLOAD_FILE_TEXT_1 = 'Preencha os campos para adicionar um documento';

var hasFile = false;

const UploadFiles = () => {
  const route = useRoute();
  const routeParams = route.params;

  let procedureId: string = '';

  if (typeof routeParams === 'string') {
    procedureId = routeParams;
  } else if (
    typeof routeParams === 'object' &&
    routeParams !== null &&
    'procedureId' in routeParams
  ) {
    procedureId = routeParams.procedureId as string;
  }

  let procedureType: string = '';

  if (typeof routeParams === 'string') {
    procedureType = routeParams;
  } else if (
    typeof routeParams === 'object' &&
    routeParams !== null &&
    'procedureType' in routeParams
  ) {
    procedureType = routeParams.procedureType as string;
  }

  let procedureNumber: string = '';

  if (typeof routeParams === 'string') {
    procedureNumber = routeParams;
  } else if (
    typeof routeParams === 'object' &&
    routeParams !== null &&
    'procedureNumber' in routeParams
  ) {
    procedureNumber = routeParams.procedureNumber as string;
  }

  const [fileData, setFileData] = useState({
    urlFile: {} as any,
    name: '',
    procedureId: procedureId,
    date: '',
  });

  const [fileDataErrors, setFileDataErrors] = useState({
    urlFile: '',
    name: '',
    date: '',
  });

  const uploadFile = useUploadFile();

  const handleSetFile = (uploadFile: any) => {
    hasFile = true;
    setFileDataErrors((prevData) => ({ ...prevData, urlFile: '' }));
    setFileData((prevData) => ({ ...prevData, urlFile: uploadFile }));
  };

  const handleSetName = (text: string) => {
    setFileDataErrors((prevData) => ({ ...prevData, name: '' }));
    setFileData((prevData) => ({ ...prevData, name: text }));
  };

  const handleSetDate = (text: string) => {
    setFileDataErrors((prevData) => ({ ...prevData, date: '' }));
    setFileData((prevData) => ({
      ...prevData,
      date: text,
    }));
  };

  const handleSaveFile = () => {
    try {
      validateFileForm();
      fileData.name = changeNameType() || fileData.name;
      fileData.procedureId = procedureId;
      if (fileData.urlFile && fileData.name && fileData.date) {
        uploadFile.mutate(fileData, {
          onSuccess: () => {
            setFileData({
              urlFile: {} as any,
              name: '',
              procedureId: '',
              date: '',
            });
            hasFile = false;
            router.replace('/home/');
          },
          onError: (error) => {
            setFileData({
              urlFile: {} as any,
              name: '',
              procedureId: '',
              date: '',
            });
            hasFile = false;
            console.error('Erro ao fazer upload: ', error);
          },
        });
      }
    } catch (e) {
      console.error('Erro na conversão do arquivo: ', e);
    }
  };

  const changeNameType = () => {
    const isImage =
      fileData.urlFile.assets![0].type !== undefined &&
      fileData.urlFile.assets![0].type === 'image';
    const isPdf =
      fileData.urlFile.assets![0].mimeType !== undefined &&
      fileData.urlFile.assets![0].mimeType === 'application/pdf';

    if (fileData.name !== '') {
      if (isImage) {
        return fileData.name + '.' + fileData.urlFile.assets![0].uri.split('.').slice(-1);
      }
      if (isPdf) {
        return fileData.name + '.pdf';
      } else {
        console.error('Formato de documento enviado para upload inválido');
      }
    }
  };

  const validateFileForm = () => {
    if (!hasFile) {
      setFileDataErrors((prevData) => ({
        ...prevData,
        urlFile: 'Anexe o arquivo a ser cadastrado',
      }));
    }
    if (!fileData.name) {
      setFileDataErrors((prevData) => ({ ...prevData, name: 'Preencha o nome do anexo' }));
    }
    if (!fileData.date) {
      setFileDataErrors((prevData) => ({ ...prevData, date: 'Preencha a data de abertura' }));
    }
  };

  const handleCancelButton = () => {
    setFileData({
      urlFile: {} as any,
      name: '',
      procedureId: '',
      date: '',
    });
    setFileDataErrors({
      urlFile: '',
      name: '',
      date: '',
    });
    hasFile = false;
    router.replace('/criminal_procedure_visualization/');
  };

  return (
    <View style={styles.container}>
      <CustomHeader
        title="Anexos"
        subtitle={
          procedureType == 'PROCESS'
            ? 'Processo nº ' + procedureNumber
            : 'Ocorrência nº ' + procedureNumber
        }
        description={UPLOAD_FILE_TEXT_1}
      ></CustomHeader>
      <KeyboardAwareScrollView scrollEnabled={false}>
        <View style={styles.content}>
          <View style={styles.inputs}>
            <InputText
              state={fileData.name}
              handleChange={handleSetName}
              label={'Nome do anexo'}
              isInvalid={true}
            />
            {fileDataErrors.name !== '' && (
              <Text variant="bodyMedium" style={styles.inputErrorText}>
                {fileDataErrors.name}
              </Text>
            )}
            <DatePicker onSelectDate={handleSetDate} value={fileData.date} />
            {fileDataErrors.date !== '' && (
              <Text variant="bodyMedium" style={styles.inputErrorText}>
                {fileDataErrors.date}
              </Text>
            )}
            <View style={styles.uploadButton}>
              <UploadFile onFileSelect={handleSetFile} />
              {fileDataErrors.urlFile !== null && (
                <Text variant="bodyMedium" style={styles.inputErrorText}>
                  {fileDataErrors.urlFile}
                </Text>
              )}
            </View>
          </View>
          <View style={styles.buttons}>
            <Button value={'Finalizar'} onClick={handleSaveFile}></Button>
            <Button value={'Cancelar'} type={1} onClick={handleCancelButton}></Button>
          </View>
        </View>
      </KeyboardAwareScrollView>
    </View>
  );
};

const styles = StyleSheet.create({
  container: {
    display: 'flex',
    width: '100%',
    height: '100%',
    backgroundColor: colors.BACKGROUND,
    overflowY: 'scroll',
    margin: 'auto',
  },
  content: {
    width: '100%',
    height: '100%',
    padding: '12%',
    justifyContent: 'space-around',
  },

  inputs: {
    width: '100%',
  },

  uploadButton: {
    marginTop: '10%',
  },

  buttons: {
    gap: 10,
    marginBottom: '10%',
    justifyContent: 'center',
    alignItems: 'center',
    marginTop: '10%',
  },
  inputErrorText: {
    color: colors.VERMILION,
    marginTop: -5,
    fontSize: 12,
    marginLeft: '2%',
  },
});

export default UploadFiles;
