import React, { useState } from 'react';
import { View, Text, TouchableOpacity, StyleSheet } from 'react-native';
import { FontAwesome } from '@expo/vector-icons';

import colors from '../../styles/colors';

interface AccordionProps {
  title: string;
  description: string;
	id?: string;
}

const Accordion: React.FC<AccordionProps> = ({ title, description, id }) => {
  const [isExpanded, setIsExpanded] = useState(false);

  const styles = StyleSheet.create({
    container: {
      minWidth: '100%',
      borderRadius: 20,
      backgroundColor: colors.WHITE,
      borderWidth: 1,
      borderColor: colors.SELECTIVE_YELLOW,
      shadowColor: 'rgba(0, 0, 0, 0.25)',
      display: 'flex',
    },
    title: {
      fontSize: 18,
      fontWeight: '600',
      width: '85%',
      flexShrink: 1,
      flexWrap: 'wrap',
      height: '100%'
    },
    description: {
      marginTop: 5,
      fontSize: 16,
      margin: 20,
      textAlign: 'justify',
      maxWidth: '100%',
    },
    accordion: {
      display: 'flex',
      flexDirection: 'row',
      justifyContent: 'space-between',
      alignItems: 'center',
      marginHorizontal: 20,
      marginVertical: 20,
    },
    fontAwesome: {
      /* transitionDuration não parece ser aceito neste componente */
      // transitionDuration: "0.1s",
      transform: [{rotate: isExpanded ? "180 deg" : "0 deg"}],
    }
  });

  const toggleAccordion = () => {
    setIsExpanded(!isExpanded);
  };

  return (
    <View style={styles.container} id={id}>
      <TouchableOpacity onPress={toggleAccordion} style={styles.accordion} >
        <Text style={styles.title}>{title}</Text>
        <FontAwesome
          name="angle-down"
          size={25}
          style={styles.fontAwesome}
        />
      </TouchableOpacity>
      {isExpanded && (
        <Text style={styles.description} id={'text-' + id}>{description}</Text>
      )}
    </View>
  );
};

export default Accordion;
