import { LinearGradient } from 'expo-linear-gradient';
import * as React from 'react';
import { StyleSheet, TextStyle, TouchableOpacity, View } from 'react-native';
import { Text } from 'react-native-paper';
import colors from '../../styles/colors';

interface IButtonProps {
  readonly value: string;
  readonly onClick: Function;
  readonly testID?: string;
  readonly disabled?: boolean;
  readonly type?: number;
	readonly id?: string;
}

const styles = StyleSheet.create({
  buttonComponent: {
    display: 'flex',
    borderRadius: 60,
    height: 62,
    justifyContent: 'center',
    alignItems: 'center',
  },
  buttonComponentWhite: {
    display: 'flex',
    borderRadius: 60,
    height: 62,
    justifyContent: 'center',
    alignItems: 'center',
    borderColor: colors.SELECTIVE_YELLOW,
    borderWidth: 3,
  },
  disabledStyle: {
    opacity: 0.5,
    pointerEvents: 'none',
  },
  button: {
    width: '100%',
  },
});

export default function ButtonComponent({ onClick, disabled, testID, id, value, type = 0 }: IButtonProps) {
  const buttonStyles = [styles.button, disabled ? styles.disabledStyle : {}];
  const gradientColors = type === 1 ? ['white', 'white'] : ['#FFB703', '#FB8500'];
  const textStyle: TextStyle = {
    color: type === 1 ? colors.SELECTIVE_YELLOW : 'white',
    fontWeight: 'bold',
  };

  return (
    <View style={buttonStyles}>
      <TouchableOpacity
        onPress={() => !disabled && onClick()}
        disabled={disabled}
        testID={testID}
				id={id}
        activeOpacity={disabled ? 1 : 0.7}
      >
        <LinearGradient
          colors={gradientColors}
          start={{ x: 0, y: 0.5 }}
          end={{ x: 1, y: 0.5 }}
          style={type === 1 ? styles.buttonComponentWhite : styles.buttonComponent}
        >
          <Text style={textStyle}>
            {value.toUpperCase()}
          </Text>
        </LinearGradient>
      </TouchableOpacity>
    </View>
  );
}
