import { FontAwesome } from '@expo/vector-icons';
import React, { useState } from 'react';
import { Pressable, StyleSheet, View } from 'react-native';
import DateTimePickerModal from 'react-native-modal-datetime-picker';
import InputText from '../input/input';

interface DatePickerProps {
  onSelectDate: (date: string) => void;
	value: string;
	id?: string;
}

const DatePicker = ({ onSelectDate, value, id }: DatePickerProps) => {
  const [isDatePickerVisible, setIsDatePickerVisible] = useState(false);

  const showDatePicker = () => {
    setIsDatePickerVisible(true);
  };

  const hideDatePicker = () => {
    setIsDatePickerVisible(false);
  };

  const handleConfirm = (e: React.SetStateAction<Date>) => {
    hideDatePicker();
    if (e) {
      onSelectDate(e.toLocaleString().slice(0, 10).replaceAll(',', ''));
    }
  };

  return (
    <View style={styles.container} id={id}>
      <Pressable onPress={showDatePicker}>
        <InputText
          readonly
          label="Quando foi aberto?"
          state={value}
					id='date-picker-input-field'
          rightIcon={
            <FontAwesome
              onPress={showDatePicker}
              name="calendar"
              color={'#FFB703'}
              size={25}
              style={styles.icon}
            />
          }
        />
      </Pressable>
      <DateTimePickerModal
        isVisible={isDatePickerVisible}
        mode="date"
        onConfirm={handleConfirm}
        onCancel={() => setIsDatePickerVisible(false)}
      ></DateTimePickerModal>
    </View>
  );
};

const styles = StyleSheet.create({
  container: {
    width: '100%',
  },
  icon: { marginRight: 10 },
});

export default DatePicker;
