import React from 'react';
import { View, Text, StyleSheet, TouchableOpacity } from 'react-native';
import { FontAwesome } from '@expo/vector-icons';
import * as Sharing from 'expo-sharing';
import colors from '../../styles/colors';
import { useDownloadFile } from '../../api/api/files/queries';
import { router } from 'expo-router';


interface Props {
  crimeDate: string;
  procedureSize: string;
  documentType: string;
  id: string;
}

const DocumentComponent: React.FC<Props> = ({ id, procedureSize, crimeDate, documentType }) => {

  const handleDownload = async () => {
    const downloadFile = await useDownloadFile(id, documentType)
    const fileData = await downloadFile.downloadAsync();

    switch (fileData!.status) {
      case 200:
        Sharing.shareAsync(fileData!.uri, { dialogTitle: "Compartilhar Documento" });
        break;
      case 401:
        router.push({ pathname: '/home/', params: { signOff: 'true' } });
      default:
        console.error("Ocorreu um erro ao baixar o documento: ", fileData!.status);
        break;
    }

  };


  return (
    <View style={styles.container}>
      <View style={styles.cardHigherPart}>
        <View style={styles.downloads}>
          <TouchableOpacity style={styles.download} onPress={() => handleDownload()}>
            <FontAwesome name="download" size={18} color={colors.SELECTIVE_YELLOW} />
          </TouchableOpacity>
        </View>

        <View style={styles.image}>
          <FontAwesome
            name="copy"
            style={{ transform: 'scaleX(-1)' }}
            size={65}
            color={colors.SELECTIVE_YELLOW}
          />
        </View>

        <Text
          numberOfLines={2}
          ellipsizeMode="tail"
          style={[
            { color: colors.EERIE_BLACK },
            { alignSelf: 'center' },
            { width: '95%' },
            { marginBottom: '15%' },
            { fontSize: 14 },
            { textAlign: 'center' },
            { fontWeight: 'bold' },
          ]}
        >
          {documentType}
        </Text>
      </View>

      <View style={styles.cardLowerPart}>
        <Text
          style={[
            styles.text,
            { color: 'white' },
            { marginLeft: 10 },
            { fontSize: 12 },
            { alignSelf: 'center' },
          ]}
        >
          {procedureSize}
        </Text>
        <Text
          style={[
            styles.text,
            { color: 'white' },
            { marginRight: 10 },
            { alignSelf: 'center' },
            { fontSize: 12 },
          ]}
        >
          {'Data: '}
          {crimeDate}
        </Text>
      </View>
    </View>
  );
};

const styles = StyleSheet.create({
  container: {
    display: 'flex',
    width: 160,
  },

  cardHigherPart: {
    display: 'flex',
    backgroundColor: '#FFFFFF',
    borderTopLeftRadius: 10,
    borderTopRightRadius: 10,
    width: '100%',
    height: 180,
    flexDirection: 'column',
    justifyContent: 'space-between',
    alignItems: 'center',
    shadowColor: '#000',
    shadowOffset: {
      width: 0,
      height: 3,
    },
    shadowOpacity: 0.3,
    shadowRadius: 2,
    elevation: 5,
  },
  cardLowerPart: {
    backgroundColor: '#FFB703',
    borderBottomLeftRadius: 10,
    borderBottomRightRadius: 10,
    height: 30,
    display: 'flex',
    flexDirection: 'row',
    justifyContent: 'space-between',
    shadowColor: '#000',
    shadowOffset: {
      width: 0,
      height: 3,
    },
    shadowOpacity: 0.3,
    shadowRadius: 2,
    elevation: 5,
  },
  image: {
    margin: 'auto',
    display: 'flex',
    alignSelf: 'center',
    marginTop: '12%',
  },

  download: {
    display: 'flex',
    transform: [{ scale: 1.2 }],
    marginRight: 15,
    marginTop: 10,
  },
  text: {
    textAlign: 'left',
    fontWeight: '700',
    fontSize: 7.8,
    flexShrink: 1,
    flexWrap: 'wrap-reverse',
  },

  downloads: {
    paddingTop: '2%',
    marginTop: '5%',
    marginLeft: '80%',
  },
});

export default DocumentComponent;
