import { FontAwesome } from '@expo/vector-icons';
import React, { useState } from 'react';
import { StyleSheet, Text, TouchableOpacity, View } from 'react-native';
import colors from '../../styles/colors';
import InputText from '../input/input';

export type Option = {
  id: string;
  name: string;
};

interface DropdownProps {
  placeholder: string;
  options: Option[];
  onSelect: (option: Option) => void;
  selectedValue?: string;
	id?: string;
}

const styles = StyleSheet.create({
  container: {
    zIndex: 1,
    width: '100%',
  },
  dropdownContent: {
    borderBottomLeftRadius: 10,
    borderBottomRightRadius: 10,
    backgroundColor: colors.WHITE,
    position: 'absolute',
    top: 50,
    left: 0,
    right: 0,
    borderWidth: 1,
    borderColor: colors.ANTI_FLASH_WHITE,
    borderTopWidth: 0,
    shadowColor: 'rgba(0, 0, 0, 0.25)',
    shadowOffset: {
      width: 0,
      height: 3,
    },
    shadowOpacity: 0.3,
    shadowRadius: 2,
    elevation: 5,
  },
  option: {
    padding: 16,
    borderBottomWidth: 1,
    borderBottomColor: colors.ANTI_FLASH_WHITE,
  },
  dropdown: {
    display: 'flex',
    flexDirection: 'row',
    justifyContent: 'space-between',
    alignItems: 'center',
  },
});

const Dropdown: React.FC<DropdownProps> = ({ placeholder, selectedValue, options, id, onSelect }) => {
  const [expanded, setExpanded] = useState(false);

  const toggleDropdown = () => {
    setExpanded(!expanded);
  };

  const handleSelect = (option: Option) => {
    onSelect(option);
    toggleDropdown();
  };

  return (
    <View style={styles.container} id={id}>
      <TouchableOpacity onPress={toggleDropdown} style={styles.dropdown}>
        <InputText
          state={selectedValue}
          label={placeholder}
          readonly
          rightIcon={
            <FontAwesome
              onPress={toggleDropdown}
              name="angle-down"
              size={25}
              style={
                {
                  transform: `rotate(${expanded ? '180' : '0'}deg)`,
                } as any
              }
            />
          }
        />
      </TouchableOpacity>

      {expanded && (
        <View style={styles.dropdownContent}>
          {options.map((item) => (
            <TouchableOpacity
              key={item.id}
							id={item.id}
              onPress={() => handleSelect(item)}
              style={styles.option}
            >
              <Text>{item.name}</Text>
            </TouchableOpacity>
          ))}
        </View>
      )}
    </View>
  );
};

export default Dropdown;

