import React, { ReactElement } from 'react';
import { FontAwesome } from "@expo/vector-icons";
import {
  View,
  Text,
  StyleProp,
  ViewStyle,
  Pressable
} from 'react-native';
import {
  Menu,
  MenuDivider,
  Position
} from '@breeffy/react-native-popup-menu';
import colors from '../../styles/colors';

interface ElementToStickProps {
  style?: StyleProp<ViewStyle>;
  showMenu: Function
}

const ElementToStick = React.forwardRef<View, ElementToStickProps>(
  ({ showMenu }, ref) => {
    const onPress = () => showMenu();
    return (
      <Pressable ref={ref} onPress={onPress} style={{ justifyContent: "flex-start", alignItems: "center", height: 75, width: 30, elevation: 6 }}>
        <FontAwesome name="ellipsis-h" size={20} color={colors.SELECTIVE_YELLOW} />
      </Pressable>
    );
  }
);

const App = ({ children }: { children: ReactElement | ReactElement[] }) => {
  let elementRef = React.createRef<Text>();
  let menuRef: Menu | null = null;

  if (!Array.isArray(children)) children = [children];

  const setMenuRef: (instance: Menu | null) => void = (ref) => (menuRef = ref);
  const showMenu = () => {
    menuRef?.show(elementRef.current, Position.TOP_CENTER);
  };

  return (
    <>
      <View
        style={{
          padding: 0,
          margin: 0,
        }}
      >
        <ElementToStick ref={elementRef} showMenu={showMenu} />
        <Menu ref={setMenuRef}>
          {children.map((component, index) => {
            return (
              <View key={`popup-menu-${index}`}>
                <View style={{ padding: 20, width: "100%" }}>
                  {component}
                </View>
                <MenuDivider />
              </View>
            )
          })}
        </Menu>
      </View>
    </>
  );
};

export default App;