import React from 'react';
import { StyleSheet, Text, View } from 'react-native';
import colors from '../../styles/colors';
import ReturnPageButton from '../returnPageButton/returnPageButton';
import { router } from 'expo-router';

interface HeaderProps {
  title: string;
  subtitle?: string;
  description?: string;
  returnRoute?: string;
}

const CustomHeader: React.FC<HeaderProps> = ({ title, subtitle, description, returnRoute }) => {
  return (
    <View style={[{ backgroundColor: colors.BACKGROUND }]}>
      <ReturnPageButton onPress={()=>{ returnRoute ? router.push(returnRoute as any) : router.back() }}/>
      <View style={styles.titleContainer}>
        <Text style={styles.title}>{title}</Text>
        <Text style={styles.subtitle}>{subtitle}</Text>
      </View>
      <View style={styles.orangeLine} />
      <View>
        <Text style={styles.description}>{description}</Text>
      </View>
    </View>
  );
};

const styles = StyleSheet.create({
  container: {
    backgroundColor: colors.BACKGROUND,
  },
  titleContainer: {
    alignItems: 'center',
    justifyContent: 'center',
    padding: 25,
    marginTop: 30,
  },
  orangeLine: {
    width: '100%',
    backgroundColor: colors.UT_ORANGE,
    height: 5,
    marginBottom: 10,
  },
  bottomContainer: {
    backgroundColor: colors.BACKGROUND,
    paddingRight: 10,
    paddingLeft: 10,
    paddingBottom: 10,
    flex: 1,
  },
  subtitleContainer: {
    alignItems: 'center',
    justifyContent: 'center',
    marginTop: 20,
    fontColor: colors.VERMILION,
  },
  title: {
    fontWeight: 'bold',
    fontSize: 25,
    marginBottom: 5,
    alignSelf: 'center',
  },
  subtitle: {
    textAlign: 'center',
    fontSize: 14,
    fontWeight: 'bold',
    color: colors.EERIE_BLACK,
  },
  description: {
    fontWeight: '600',
    fontSize: 16,
    textAlign: 'left',
    color: colors.GRAY,
    margin: 10
  },
});

export default CustomHeader;

