import React, { useState, FC, ReactElement } from 'react';
import { Card, Title, Modal, Portal, IconButton } from 'react-native-paper';
import { View, StyleSheet } from 'react-native';
import colors from '../../styles/colors';
import Markdown from '@jonasmerlin/react-native-markdown-display/';


interface InfoCardProps {
  title: string;
  Icon?: () => ReactElement;
  description: string;
	id?: string
}

const InfoCard: FC<InfoCardProps> = ({ title, Icon, description, id }) => {
  const [visible, setVisible] = useState(false);

  const showModal = () => setVisible(true);

  const hideModal = () => setVisible(false);

  return (
    <View>
      <Card style={styles.card} onPress={showModal} id={id}>
        <Card.Content style={styles.content}>
          <View style={styles.iconTitleContainer}>
            {Icon && <Icon />}
            <Title style={styles.title}>{title}</Title>
          </View>
        </Card.Content>
      </Card>

      <Portal>
        <Modal visible={visible} onDismiss={hideModal} contentContainerStyle={styles.modal}>
          <IconButton id={id + '-modal-close-btn'} icon="close" onPress={hideModal} />
          <Markdown>{description}</Markdown>
        </Modal>
      </Portal>
    </View>
  );
};

const styles = StyleSheet.create({
  card: {
    marginTop: 10,
    marginBottom: 10,
    borderRadius: 25,
		height: 230,
		width: 200,
		justifyContent: 'center',
		backgroundColor: colors.WHITE
  },
  content: {
		display: 'flex',
		paddingTop: 35
  },
  iconTitleContainer: {
    alignItems: 'center',
  },
  title: {
		textAlign: 'center',
		paddingTop: '10%',
    marginTop: 3,
		fontWeight: 'bold'
  },
  modal: {
    padding: 20,
    backgroundColor: 'white',
    margin: 20,
    borderWidth: 1,
    borderColor: colors.SELECTIVE_YELLOW,
    borderRadius: 15,
  },
});

export default InfoCard;
