import React from "react";

import { View, StyleSheet } from "react-native";
import { Text } from "react-native-paper";
import colors from "../../styles/colors";
import Done from "../../assets/images/done_green.svg";
import Fail from "../../assets/images/fail_red.svg";

const styles = StyleSheet.create({
  passwordHintWrapper: {
    display: "flex",
    flexDirection: "row",
    alignItems: "center",
    gap: 10,
  },
  icon: {
    width: 12,
    height: 12,
  },
  passwordHintWrapper2:{
    display: "flex",
    flexDirection: "row",
    marginLeft: "4%",
    alignItems: "center",
    gap: 10,
  },
});

interface HintProps {
  isValid: boolean | RegExpMatchArray | null;
  label: string;
  type?: number;
}

export default function Hint(props: HintProps) {
    const { type } = props;
    const inputStyle =
      type === 1
        ? styles.passwordHintWrapper2 
        : styles.passwordHintWrapper;

  return (
    <View style={inputStyle} testID="hint">
      {props.isValid ? (
        <Done style={styles.icon} testID="done-icon" />
      ) : (
        <Fail style={styles.icon} testID="fail-icon" />
      )}
      <Text
        testID="label-text"
        variant="bodyMedium"
        style={{ color: props.isValid ? colors.LIME_GREEN : colors.VERMILION }}
      >
        {props.label}
      </Text>
    </View>
  );
}
