import React, { useCallback, useEffect, useState } from 'react';
import { View, Text, StyleSheet, TouchableOpacity } from 'react-native';
import colors from '../../styles/colors';
import DocumentDuplicate from '../../assets/images/documentDuplicate.svg';
import ShareComponent from '../shareComponent/shareComponent';
import AsyncStorage from '@react-native-async-storage/async-storage';
import { jwtDecode } from 'jwt-decode';
import Hamburguer from "../dropdrown/hamburger";
import DeleteButton from "../button/delete";
import { useDeleteCriminalProcedure } from "../../api/api/criminal-procedures/requests"

interface Props {
  procedureType: string;
  procedureNumber: string;
  crimeType: string;
  crimeLocation: string;
  crimeDate: string;
	onPress: () => void;
	id?: string;
}

interface JwtPayload {
  name: string;
  preferred_username: string;
}

interface User {
  name: string;
  cpf: string;
}

interface JwtPayload {
  name: string;
  preferred_username: string;
}

interface User {
  name: string;
  cpf: string;
}

const ProcedureCard: React.FC<Props> = ({
  procedureType,
  procedureNumber,
  crimeType,
  crimeLocation,
  crimeDate,
	id,
	onPress,
}) => {
  const [user, setUser] = useState<User>({} as User);

  const getToken = useCallback(async () => {
    await AsyncStorage.getItem('TOKEN_API')
      .then((token) => {
        if (!token) return;
        const decode = jwtDecode<JwtPayload>(token);
        const tokenUser = { name: decode.name, cpf: decode.preferred_username };

        setUser(tokenUser);
      })
      .catch((error) => {
        console.error('Error reading TOKEN_API from AsyncStorage: ', error);
      });
  }, []);

  useEffect(() => {
    getToken();
  }, [getToken]);

  return (
  
	<TouchableOpacity onPress={onPress}>
    <View style={styles.container} id={id}>
        <View style={styles.cardHigherPart}>
          <View style={styles.image}>{<DocumentDuplicate />}</View>
          <View style={styles.info}>
            <Text style={[styles.text, { marginBottom: 10 }]}>
              {procedureType + ' n° ' + procedureNumber}
            </Text>
            <Text style={styles.text}>
              {'Tipo de crime: ' + crimeType}
            </Text>
            <Text style={[styles.text, { marginBottom: 10 }]}>
              {'Local: ' + crimeLocation}
            </Text>
          </View>

        <View>
          <Hamburguer>
            <ShareComponent
              name={user.name}
              cpf={user.cpf}
              crimeType={crimeType}
              crimeDate={crimeDate}
              crimeLocation={crimeLocation}
              procedureType={procedureType}
              procedureNumber={procedureNumber}
              documentUri={''}
              buttonText={''}
            />
            <DeleteButton deleteQuery={useDeleteCriminalProcedure} id={procedureNumber} />
          </Hamburguer>

        </View>
      </View>

      <View style={styles.cardLowerPart}>
        <Text style={[styles.text, { color: 'white' }, { marginLeft: 18 }, { fontSize: 12 }]}>
          {'Data: '}
          {crimeDate}
        </Text>
      </View>
    </View>
		</TouchableOpacity>
);}

const styles = StyleSheet.create({
  container: {
    display: 'flex',
    width: '100%',
  },

  cardHigherPart: {
    backgroundColor: colors.BACKGROUND,
    borderTopLeftRadius: 5,
    borderTopRightRadius: 5,
    marginTop: 7,
    marginHorizontal: 1,
    padding: 10,
    flexDirection: 'row',
    justifyContent: 'space-between',
    alignItems: 'center',

    shadowColor: colors.EERIE_BLACK,
    shadowOffset: {
      width: 0,
      height: 3,
    },
    shadowOpacity: 0.3,
    shadowRadius: 2,
    elevation: 5,
  } as any,

  cardLowerPart: {
    backgroundColor: colors.SELECTIVE_YELLOW,
    borderBottomLeftRadius: 10,
    borderBottomRightRadius: 10,
    height: 20,
    display: 'flex',
    justifyContent: 'center',
    marginBottom: 7,
    marginHorizontal: 1,
    shadowColor: colors.EERIE_BLACK,
    shadowOffset: {
      width: 0,
      height: 3,
    },
    shadowOpacity: 0.3,
    shadowRadius: 2,
    elevation: 5,
  },
  image: {
    display: 'flex',
    alignSelf: 'center',
    height: 60,
    width: 60,
    flexDirection: 'row',
  },

  shareImage: {
    height: "100%"
  },
  text: {
    textAlign: 'left',
    fontWeight: '700',
    fontSize: 14,
    flexWrap: 'wrap-reverse',
  },
  info: {
    display: 'flex',
    flexShrink: 1
  },
});

export default ProcedureCard;
