import React from "react";
import { View, TouchableOpacity, Text } from 'react-native';
import { printToFileAsync } from 'expo-print';
import { shareAsync } from 'expo-sharing';
import { FontAwesome } from '@expo/vector-icons';
import colors from '../../styles/colors';

interface Props {
  name: string;
  cpf: string;
  crimeType: string;
  crimeDate: string;
  crimeLocation: string;
  procedureType: string;
  procedureNumber: string;
  documentUri: string;
  buttonText: string;
}

const ShareComponent: React.FC<Props> = ({
  name,
  cpf,
  crimeType,
  crimeDate,
  crimeLocation,
  procedureType,
  procedureNumber,
}) => {
  const handleShare = async () => {
    const html = `
<html>
  <head>
    <style>
      body {
        text-align: center;
        font-family: Arial, sans-serif;
      }
      h1 {
        font-size: 24px;
        margin: 0;
      }
      h2 {
        font-size: 18px;
      }
      .section {
        margin-top: 20px;
      }
      .center {
        text-align: center;
      }
      .bottom {
        position: absolute;
        bottom: 30px;
        left: 0;
        right: 0;
      }
      .bottom2 {
        position: absolute;
        bottom: 55px;
        left: 0;
        right: 0;
      }
      header {
        margin-top: 65px;
      }
    </style>
  </head>
  <body>
  <header>
  <h1>PROCESSO CRIMINAL Nº ${procedureNumber}</h1>
  <div class="section">
    <h2>CRIME DE ${crimeType.toUpperCase()}</h2>
    <p>OCORRIDO NO DIA: ${crimeDate}</p>
    <p>LOCAL DO CRIME: ${crimeLocation.toUpperCase()}</p>
  </div>
</header>
    <div class="bottom2">
      <h1>VÍTIMA: ${name.toUpperCase()}</h1>
      <p>CPF: ${cpf}</p>
    </div>
    <div class="bottom">
      <h1>${procedureType.toUpperCase()}</h1>
    </div>
  </body>
</html>
    `;

    const generatePdf = async () => {
      const file = await printToFileAsync({
        html: html,
        base64: false,
      });

      await shareAsync(file.uri);
    };

    generatePdf();
  };

  return (
    <TouchableOpacity onPress={handleShare}>
      <View style={{ flexDirection: "row", alignItems: "flex-start", gap: 10 }}>
        <FontAwesome name={'share-alt'} size={18} color={colors.SELECTIVE_YELLOW} ></FontAwesome>
        <Text>Compartilhar</Text>
      </View>
    </TouchableOpacity>
  );
};

export default ShareComponent;
