import React, { useState } from 'react';
import { Card, Modal } from 'react-native-paper';
import { StyleSheet, TouchableOpacity, Text, View } from 'react-native';
import colors from '../../styles/colors';
import { Ionicons } from '@expo/vector-icons';
import general from '../../styles/general';
import * as DocumentPicker from 'expo-document-picker';
import * as ImagePicker from 'expo-image-picker';

type onFileSelect = any;

const UploadFiles: React.FC<{ onFileSelect: onFileSelect }> = ({ onFileSelect }) => {
  const [isModalVisible, setModalVisible] = useState(false);
	

  const toggleModal = () => {
    setModalVisible(!isModalVisible);
  };

  const closeModal = () => {
    setModalVisible(false);
  };

  const pickPDF = async () => {
    try {
      const result = await DocumentPicker.getDocumentAsync({
        type: 'application/pdf',
      });
			onFileSelect(result)
    } catch (err) {
		}
  };
	
	const pickImage = async () => {
		const result = await ImagePicker.launchImageLibraryAsync({
			mediaTypes: ImagePicker.MediaTypeOptions.Images,
    });
		onFileSelect(result)
  };
	
  const useCamera = async () => {
		const permissionResult = await ImagePicker.requestCameraPermissionsAsync();
    if(permissionResult.granted === false) {
			alert('É necessário permitir o acesso à câmera!');
      return;
    }
    else{
			const result = await ImagePicker.launchCameraAsync({
			});
			onFileSelect(result)
    };
  };

  return (
    <View>
      <Card style={styles.card}>
        <Card.Content style={styles.content}>
          <Card.Actions>
            <TouchableOpacity onPress={toggleModal}>
              <Ionicons name="ios-cloud-upload-outline" size={60} style={styles.uploadButton} />
              <Text style={styles.text}>Clique aqui para fazer o envio do documento</Text>
            </TouchableOpacity>
          </Card.Actions>
        </Card.Content>
      </Card>

      <Modal visible={isModalVisible} onDismiss={toggleModal}>
        <View style={styles.modalContent}>
          <View style={styles.closeButton}>
            <TouchableOpacity onPress={closeModal}>
              <Ionicons name="ios-close" size={32} color={colors.GRAY}/>
            </TouchableOpacity>
          </View>
          <View style={styles.iconView}>
            <TouchableOpacity onPress={pickPDF}>
              <Ionicons name="ios-folder" style={styles.icon} size={80} />
              <Text style={styles.text}>Arquivos</Text>
            </TouchableOpacity>
          </View>
          <View style={styles.iconView}>
            <TouchableOpacity>
              <Ionicons name="ios-images" style={styles.icon} size={80} onPress={pickImage}/>
              <Text style={styles.text}>Galeria</Text>
            </TouchableOpacity>
          </View>
          <View style={styles.iconView}>
            <TouchableOpacity>
              <Ionicons name="ios-camera" style={styles.icon} size={80} onPress={useCamera} />
              <Text style={styles.text}>Câmera</Text>
            </TouchableOpacity>
          </View>
        </View>
      </Modal>
    </View>
  );
};

const styles = StyleSheet.create({
  card: {
    alignItems: 'center',
    backgroundColor: colors.BACKGROUND,
    borderRadius: 5,
  },
  content: {
    backgroundColor: colors.BACKGROUND,
    alignItems: 'center',
  },
  uploadButton: {
		alignSelf: 'center',
		justifyContent: 'center',
		color: colors.SELECTIVE_YELLOW
  },
  closeButton: {
    position: 'absolute',
    top: 10,
    right: 10,
  },
  icon: {
    color: colors.SELECTIVE_YELLOW,
  },
  text: {
    textAlign: 'center',
    fontSize: general.body1.fontSize,
    fontWeight: general.body1.fontWeight,
    color: colors.GRAY,
  },
  modalContent: {
    backgroundColor: colors.WHITE,
    borderTopRightRadius: 20,
    borderTopLeftRadius: 20,
    alignItems: 'center',
    width: 'auto',
    height: 263,
    boxShadow: '0px -5px 4px rgba(0, 0, 0, 0.25)',
    shadowOpacity: 0.3,
    shadowRadius: 2,
    display: 'flex',
    justifyContent: 'space-around',
    flexDirection: 'row',
  },
  iconView: {
    paddingBottom: 60,
  },
});

export default UploadFiles;
