import React from 'react';
import { SafeAreaView, ScrollView, StyleSheet, View } from 'react-native';
import { Text } from 'react-native-paper';
import ComponentButton from '../../components/button/component_button';
import colors from '../../styles/colors';
import general from '../../styles/general';

interface VerificationScreenProps {
  headerImage: any;
  message: string;
  buttonText: string;
  onButtonPress: () => void;
}

const ValidationComponent: React.FC<VerificationScreenProps> = ({
  headerImage: HeaderImage,
  message,
  buttonText,
  onButtonPress,
}) => {
  return (
    <SafeAreaView style={styles.safeArea}>
      <ScrollView contentContainerStyle={styles.scrollView}>
        <View style={styles.container}>
          <HeaderImage style={styles.headerImage} />
          <Text style={styles.largeText}>{message}</Text>
          <View style={styles.buttonContainer}>
            <ComponentButton value={buttonText} onClick={onButtonPress} />
          </View>
        </View>
      </ScrollView>
    </SafeAreaView>
  );
};

const styles = StyleSheet.create({
  safeArea: {
    flex: 1,
  },
  scrollView: {
    flexGrow: 1,
    justifyContent: 'center',
  },
  container: {
    flex: 1,
    justifyContent: 'center',
    alignItems: 'center',
    backgroundColor: colors.WHITE,
    paddingHorizontal: '10%',
  },
  headerImage: {
    marginBottom: 20,
  },
  largeText: {
    textAlign: 'center',
    fontSize: general.header2.fontSize,
    fontWeight: general.header2.fontWeight,
    color: colors.EERIE_BLACK,
    marginVertical: 10,
  },
  buttonContainer: {
    marginTop: 90,
    width: '80%',
  },
});

export default ValidationComponent;
