import React, { useContext, useEffect, useRef, useState } from 'react';
import { Text, View, StyleSheet, TouchableOpacity, Animated } from 'react-native';
import Popover from 'react-native-popover-view';
import { WalkthroughContext } from '../../contexts/WalkthroughContext';
import { Ionicons } from '@expo/vector-icons';
import colors from '../../styles/colors';
import { LinearGradient } from 'expo-linear-gradient';

const styles = StyleSheet.create({
    buttonComponent: {
        display: 'flex',
        borderRadius: 60,
        height: 25,
        justifyContent: 'center',
        alignItems: 'center',
    },
    disabledStyle: {
        opacity: 0.5,
        pointerEvents: 'none',
    },
    button: {
        width: '30%',
    },
    textButtonWhite: {
        color: 'white',
        fontWeight: 'bold',
        fontSize: 12
    }
});

const Walkthrough = ({ walkthroughOpen, setIsWalkthroughOpen }: { walkthroughOpen: boolean, setIsWalkthroughOpen: any }) => {

    const [step, setStep] = useState(1);
    const walkthroughContext = useContext(WalkthroughContext);
    const fadeAnimation = useRef(new Animated.Value(0)).current;

    const selectStep = (step: number) => {
        switch (step) {
            case 1:
                return walkthroughContext.step1;
            case 2:
                return walkthroughContext.step2;
            case 3:
                return walkthroughContext.step3;
            case 4:
                return walkthroughContext.step4;
            default:
                setStep(1);
                return walkthroughContext.step1;
        }
    }

    const nextStep = () => {
        
        fadeAnimation.resetAnimation();

        if (selectStep(step + 1).ref.current == null) {
            setStep(step + 2);
        }
        else {
            setStep(step + 1);
        }

        fadeIn();

        if (step == 4) setIsWalkthroughOpen(false);

    }

    const fadeIn = () => {
        Animated.timing(fadeAnimation, {
            toValue: 1,
            duration: 1000,
            useNativeDriver: true,
        }).start();
    };

    useEffect(() => { fadeIn() },[])

    return (
        <Popover from={selectStep(step).ref} isVisible={walkthroughOpen} onRequestClose={() => { setIsWalkthroughOpen(false) }}>
            <View style={{ display: 'flex', flexDirection: 'column', gap: 10, padding: 7, alignItems: 'flex-end' }}>
                <TouchableOpacity onPress={() => { setIsWalkthroughOpen(false) }}>
                    <Ionicons name="ios-close" size={28} color={colors.UT_ORANGE} />
                </TouchableOpacity>
                <Animated.Text style={{ opacity: fadeAnimation }}>{selectStep(step).content}</Animated.Text>
                <Button
                    style={styles}
                    value={step == 4 ? "Finalizar" : "Próximo"}
                    onClick={() => nextStep() }
					id='walkthrough-next-step-btn'
                />
            </View>
        </Popover>
    );
};

function Button({ onClick, testID, value, id }: any) {
    return (
        <View style={styles.button}>
            <TouchableOpacity
                onPress={() => onClick()}
                testID={testID}
				id={id}
            >
                <LinearGradient
                    colors={['#FFB703', '#FB8500']}
                    start={{ x: 0, y: 0.5 }}
                    end={{ x: 1, y: 0.5 }}
                    style={styles.buttonComponent}
                >
                    <Text
                        style={styles.textButtonWhite}
                    >
                        {value.toUpperCase()}
                    </Text>
                </LinearGradient>
            </TouchableOpacity>
        </View>
    );
}

export default Walkthrough;
