import AsyncStorage from "@react-native-async-storage/async-storage";
import React, { createContext, ReactNode, useState } from "react";

interface AuthContextData {
    signed: boolean;
    token: string;
    signIn(token: string): void;
    signOut(): void;
}

export const AuthContext = createContext<AuthContextData>(
    {} as AuthContextData
);

interface AuthProviderProps {
    children: ReactNode;
}

export const AuthProvider: React.FC<AuthProviderProps> = ({ children }) => {

    function signIn(token: string) {
        AsyncStorage.setItem("TOKEN_API", token);
        setAuthentication((prevState) => ({
            ...prevState,
            signed: true,
            token: token
        }));
    }

    function signOut() {
        AsyncStorage.removeItem("TOKEN_API");
        setAuthentication((prevState) => ({
            ...prevState,
            signed: false,
        }));
    }

    const [authentication, setAuthentication] = useState<AuthContextData>({ signed: false, token: "", signIn, signOut });

    return (
        <AuthContext.Provider value={ authentication }>
            {children}
        </AuthContext.Provider>
    );
};
