import React, { createContext, ReactNode, useRef, useState } from "react";

interface WalkthroughContextData {
    step1: Step;
    step2: Step;
    step3: Step;
    step4: Step;
}

interface Step {
    ref: React.MutableRefObject<null>;
    content: string;
}

export const WalkthroughContext = createContext<WalkthroughContextData>(
    {} as WalkthroughContextData
);

interface WalkthroughProviderProps {
    children: ReactNode;
}

export const WalkthroughProvider: React.FC<WalkthroughProviderProps> = ({ children }) => {

    const step1 = useRef(null);
    const step2 = useRef(null);
    const step3 = useRef(null);
    const step4 = useRef(null);

    const initialWalkthrough = {
        step1: { ref: step1, content: "Que tal conhecer as principais funcionalidades do nosso aplicativo com um rápido tutorial?" } as Step,
        step2: { ref: step2, content: "Este botão trás você de volta para a página inicial do aplicativo." } as Step,
        step3: { ref: step3, content: "Aqui você pode adicionar informações e documentos sobre seu processo ou ocorrência." } as Step,
        step4: { ref: step4, content: "Caso queira sair da sua conta, basta clicar aqui!" } as Step,
    } as WalkthroughContextData

    const [walkthrough, setWalkthrough] = useState<WalkthroughContextData>(initialWalkthrough);

    return (
        <WalkthroughContext.Provider value={ walkthrough }>
            {children}
        </WalkthroughContext.Provider>
    );
};
